@@ -1,5 +1,5 @@
 package HackaMol::Molecule;
-$HackaMol::Molecule::VERSION = '0.033';
+$HackaMol::Molecule::VERSION = '0.034';
 #ABSTRACT: Molecule class for HackaMol
 use 5.008;
 use Moose;
@@ -8,11 +8,12 @@ use Carp;
 use Math::Trig;
 use Scalar::Util qw(refaddr);
 use MooseX::StrictConstructor;
-use MooseX::Storage;
+#use MooseX::Storage;
 
 with 'HackaMol::Roles::PhysVecMVRRole',
      'HackaMol::Roles::BondsAnglesDihedralsRole', 
-     'HackaMol::Roles::QmMolRole', Storage( 'format' => 'JSON', 'io' => 'File' );
+     'HackaMol::Roles::QmMolRole';
+#, Storage( 'format' => 'JSON', 'io' => 'File' );
 
 extends 'HackaMol::AtomGroup';
 
@@ -245,7 +246,7 @@ HackaMol::Molecule - Molecule class for HackaMol
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SYNOPSIS
 
@@ -436,18 +437,12 @@ L<Chemistry::Molecule>
 
 =item * L<HackaMol::Roles::PhysVecMVRRole>
 
-=item * L<HackaMol::Roles::PhysVecMVRRole|HackaMol::Roles::BondsAnglesDihedralsRole|HackaMol::Roles::QmMolRole|MooseX::Storage::Basic|MooseX::Storage::Format::JSON|MooseX::Storage::IO::File>
+=item * L<HackaMol::Roles::PhysVecMVRRole|HackaMol::Roles::BondsAnglesDihedralsRole|HackaMol::Roles::QmMolRole>
 
 =item * L<HackaMol::Roles::QmAtomRole>
 
 =item * L<HackaMol::Roles::QmMolRole>
 
-=item * L<MooseX::Storage::Basic>
-
-=item * L<MooseX::Storage::Format::JSON>
-
-=item * L<MooseX::Storage::IO::File>
-
 =back
 
 =head1 AUTHOR
