@@ -1,5 +1,5 @@
 package HackaMol::Roles::PhysVecMVRRole;
-$HackaMol::Roles::PhysVecMVRRole::VERSION = '0.033';
+$HackaMol::Roles::PhysVecMVRRole::VERSION = '0.034';
 # ABSTRACT: Provides the core of HackaMol Atom and Molecule classes.
 use Math::Vector::Real;
 use Math::Trig;
@@ -8,7 +8,7 @@ use Math::Trig;
 use Moose::Role;
 use Carp;
 use Data::Structure::Util qw (unbless);
-use MooseX::Storage;
+#use MooseX::Storage;
 
 #with Storage( 'format' => 'JSON', 'io' => 'File' );
 
@@ -342,7 +342,7 @@ HackaMol::Roles::PhysVecMVRRole - Provides the core of HackaMol Atom and Molecul
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SYNOPSIS
 
